@@ -7,7 +7,7 @@ use Carp;
 use vars qw($VERSION);
 use Data::Dumper;
 
-$VERSION = '2.01';
+$VERSION = '2.03';
 
 sub new {
     my $class = shift;
@@ -331,101 +331,13 @@ WWW::Search::PharmGKB - Search and retrieve information from the PharmGKB databa
 
 =head1 VERSION
 
-Version 2.00
+Version 2.02
 
 =cut
 
 =head1 SYNOPSIS
 
-    use WWW::Search::PharmGKB;
-    use Data::Dumper;
-    my $foo = WWW::Search::PharmGKB->new();
-    my $search_result = $foo->gene_search('CYP2D6');
-    print Dumper $search_result;
-
-
-=head1 METHODS
-
-=head2 new
-
-=head3 Usage:
-
-    $foo = WWW::Search::PharmGKB->new();
-	    or
-    $foo = new WWW::Search::PharmGKB;
-
-=head3 Returns:
-
-    Self
-    
-=cut
-
-=head2 gene_search
-
-=head3 Usage:
-
-    $foo->gene_search(<gene_name>);
-
-=head3 Returns:
-
-    A referenced hash. The keys are 'drugs', 'name', 'symbol', 'pathways',
-    'drugs', 'diseases', 'phenotypes', 'alternate_names', 'alternate_symbols'
-    
-=head3 Note:
-
-    all the keys contain referenced arrays as values. In the pathway value,
-    the array has  key => value pairs 'pathway' => 'pharmGKB URL' as elements.
-    All other keys have referenced array of PharmGKB IDs.
-
-=cut
-
-=head2 disease_search
-
-=head3 Usage:
-
-    $foo->disease_search(<disease_name>);
-
-=head3 Returns:
-
-    A referenced hash of pharmGKB IDs. Each ID contains 'drugs', 'names', 'pathways', 'drugs',
-    'genes', 'phenotypes'.
-    
-=head3 Note:
-
-    all the keys contain referenced arrays as values. in the pathway value,
-    the array has  key => value pairs 'pathway' => 'pharmGKB URL' as elements.
-    All other keys have referenced array of PharmGKB IDs.
-=cut
-
-=head2 drug_search
-
-=head3 Usage:
-
-    $foo->drug_search(<drug_name>);
-
-=head3 Returns:
-
-    A referenced hash of pharmGKB IDs. Each ID contains 'diseases', 'generic_names', 'trade_names',
-    'pathways', 'genes', 'phenotypes', 'category', 'classification'
-    
-=head3 Note:
-
-    all the keys contain referenced arrays as values. in the pathway value,
-    the array has  key => value pairs 'pathway' => 'pharmGKB URL' as elements.
-    All other keys have referenced array of PharmGKB IDs.
-=cut
-
-=head2 publication_search
-
-=head3 Usage:
-
-    $foo->publication_search(<something>);
-
-=head3 Returns:
-
-    A referenced hash of pharmGKB IDs. Each ID contains 'authors', 'page',
-    'volume', 'month', 'grant_id', 'cross_reference', 'title', 'abstract', 'year',
-    'journal'.
+This module will not work. The PharmGKB API doesn't exist anymore. PLEASE DO NOT USE.
 
 =cut
 
@@ -478,7 +390,7 @@ This module is based on the perl client written by Andrew MacBride (andrew@helix
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Arun Venkataraman C<arvktr@gmail.com>, all rights reserved.
+Copyright 2010 Arun Venkataraman C<arvktr@cpan.org>, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
